@@ -77,8 +77,8 @@ These command must follow the syntax defined in L<Config::Model::Loader>
 
 Example:
 
-   cme modify dpkg 'source format="(3.0) quilt"'
-   cme modify multistrap my_mstrap.conf 'sections:base source="http://ftp.fr.debian.org"'
+   cme modify dpkg 'control source format="(3.0) quilt"'
+   cme modify ssh 'Host:"*.debian.org" User=dod'
 
 Finding the right instructions to perform a modification may be
 difficult when starting from scratch.
@@ -110,7 +110,10 @@ See L<cme/"Global Options">.
 
 =item -save
 
-Force a save even if no change was done. Useful to reformat the configuration file.
+Force a save even if no change was done by user (although some minor
+change like migrating deprecated values can be done by cme). Useful to
+minimize changes and reformat the configuration file.  Running C<cme
+modify xxx -save> is equivalent to running C<cme migrate xxx>.
 
 =item -verbose
 
